/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA;
typedef struct tyObject_Table__GpIQt2f0xrasZObyH6X8bg tyObject_Table__GpIQt2f0xrasZObyH6X8bg;
typedef struct tySequence__9chP3SzkaldXzawWQCDsqqg tySequence__9chP3SzkaldXzawWQCDsqqg;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg;
typedef struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q;
typedef struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA tySequence__Mh9agqM29bm9aP5AUL1x7dZGA;
typedef struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg;
typedef struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA tyObject_Int128__9a9axPfb75jdWY25AamJewkA;
typedef struct tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA;
typedef struct tySequence__K8W16aeLg4OWxniQxtguMw tySequence__K8W16aeLg4OWxniQxtguMw;
typedef struct tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w;
typedef struct tyTuple__aGv2fk9ceddvdC01ZJC2Q2g tyTuple__aGv2fk9ceddvdC01ZJC2Q2g;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;

/* section: NIM_merge_TYPES */
struct tyObject_Table__GpIQt2f0xrasZObyH6X8bg {
tySequence__9chP3SzkaldXzawWQCDsqqg* data;
NI counter;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA {
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf;
tyObject_Table__GpIQt2f0xrasZObyH6X8bg visited;
NIM_BOOL renderSymType;
NI indent;
NI currentLine;
NIM_BOOL firstItem;
NIM_BOOL useColor;
NimStringDesc* res;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* left;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* right;
NI L;
NimStringDesc* data;
};
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__wqYjTJU9ab2ZgEFMaQc3vNA[3];
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg {
NI h;
};
struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
RootObj* val;
};
struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q {
NI counter;
tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* data;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
struct tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA {
NI h;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
};
struct tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA {
NI counter;
tySequence__K8W16aeLg4OWxniQxtguMw* data;
};
struct tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val;
};
typedef NU8 tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA;
struct tyTuple__aGv2fk9ceddvdC01ZJC2Q2g {
NI Field0;
void* Field1;
NI Field2;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA {
  TGenericSeq Sup;
  tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg data[SEQ_DECL_SIZE];
};
struct tySequence__K8W16aeLg4OWxniQxtguMw {
  TGenericSeq Sup;
  tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w data[SEQ_DECL_SIZE];
};
struct tySequence__9chP3SzkaldXzawWQCDsqqg {
  TGenericSeq Sup;
  tyTuple__aGv2fk9ceddvdC01ZJC2Q2g data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, debugSym)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initTable__avINVlbIK12XSqjy8oSlzg)(NI initialSize, tyObject_Table__GpIQt2f0xrasZObyH6X8bg* Result);
N_LIB_PRIVATE N_NIMCALL(void, value__WBlS070x2bmiH6WMBydj9bA)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* value);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__ucLvuteXMiAMAvKs77J1uw)(tyObject_Table__GpIQt2f0xrasZObyH6X8bg t, void* key, NI default_0);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___7nUN9bEb8it8esEzVF54z3Q)(tyObject_Table__GpIQt2f0xrasZObyH6X8bg* t, void* key, NI val);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, openCurly__EAEW3Bgfb2rBayBNQm2DKA)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, indentMore__EAEW3Bgfb2rBayBNQm2DKA_2)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, key__phacdxUw7oWjcmjWuQy9bkg)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, newlineAndIndent__EAEW3Bgfb2rBayBNQm2DKA_3)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, value__IoQuLXtIJvnyXSTPrJspcg)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw value);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, value__FzAGrI1bDlDZrjbkaI7wWw)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(void, value__llsVIlOlOqDWZCDMxDvp3Q)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, NI64 value);
static N_INLINE(NI, countBits64)(NU64 n);
N_LIB_PRIVATE N_NIMCALL(void, value__Hzb0vPKN9benEkKQu05NCSQ)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw value);
N_LIB_PRIVATE N_NIMCALL(void, openBracket__EAEW3Bgfb2rBayBNQm2DKA_4)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, value__ruLxBJWmZYZuNJ1guCKmNQ)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw value);
N_LIB_PRIVATE N_NIMCALL(void, comma__EAEW3Bgfb2rBayBNQm2DKA_5)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, closeBracket__EAEW3Bgfb2rBayBNQm2DKA_6)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, value__uX2gdSRLzvWLVnXyqz6jsg)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* value);
N_LIB_PRIVATE N_NIMCALL(void, value__kpJVt9cnR9aTcWW9bP5ctpOcA)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag value);
N_LIB_PRIVATE N_NIMCALL(void, value__aJLEBHPURIT7szTDyvtBUA)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw value);
N_LIB_PRIVATE N_NIMCALL(void, value__Hsy1hoKfET3FAJnWke3a8w)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw value);
N_LIB_PRIVATE N_NIMCALL(void, value__PG3EgA9a9albKasBOYELDF6A)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value);
N_LIB_PRIVATE N_NIMCALL(void, value__KUWb6zp2ipm1IVHDVNcPJQ)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw value);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___mZ66tEveFIQokq3arf8Klw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, lineInfoToStr__o5OvO09cfEJ7lAWvUTH12Yw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___UQfMnMPks8jKz20fTXQy9bQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, makeYamlString__P4HN4Rp9arTWym9cdDnUDu8Q)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, add__IM4kcMNkkOLJtqdEqSxR8A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__yShmEg9cffWxI7s5XzEKBow)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toYamlChar__WyTOYiqdW29blXR7k3pjktw)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHex__TwQ1R2wlkmY9ak7KGbc718A)(NI x, NI len);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__KOisMGxcPhz6CcSmxgwEQQ)(NI64 i);
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(NI, toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, value__22GsmbrIt7ciZ1zdjy1Jvg)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg value);
N_LIB_PRIVATE N_NIMCALL(NI, countBits32)(NU32 n);
N_LIB_PRIVATE N_NIMCALL(void, value__RbCM2UXVLll9cN4eZagDG6A)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg value);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toStrMaxPrecision__ayHojnbqAtgkZF8TXMNMzg)(NF f, NimStringDesc* literalPostfix);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, closeCurly__EAEW3Bgfb2rBayBNQm2DKA_7)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, indentLess__EAEW3Bgfb2rBayBNQm2DKA_8)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0);
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, debugType)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, debugNode)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
static N_INLINE(NI, nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo)(NI h, NI maxHash);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, mustRehash__B5utQwGyZRj1lQY2mjeMBw)(NI length, NI counter);
N_LIB_PRIVATE N_NIMCALL(void, strTableEnlarge__CVRANnnfZDXMACWb4B1HCA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(void, strTableRawInsert__SHWbts1Rvx7KpPzj7sTOjw)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** data, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2)(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab);
N_LIB_PRIVATE N_NIMCALL(NI, idTableRawGet__SaVgzV5UjaVvopbOluf3NA)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q t, NI key);
N_LIB_PRIVATE N_NIMCALL(void, idTableRawInsert__psi7yP9bBH1cFhQHDpcKjQA)(tySequence__Mh9agqM29bm9aP5AUL1x7dZGA** data, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key, RootObj* val);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___7c5Zw7H31uJfWmmhZe9aEqw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, getInt__Ml9bTZ5dXYSLBfnGRkErokw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameIgnoreBacktickGensymInfo__79a58vqHQbOF5NzKLzjPg9aA)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIdentIter__9bSCoSykDuXHhkzoBXiof6Q)(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIdentExcluding__nWv58txbq3B5NUvjC6qnSA)(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* excluding);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__R6uRTGpl30Ofaw4Ni3vawA)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NI, idNodeTableRawGet__gZVj7dpnZcnics5OMZbxkA)(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key);
N_LIB_PRIVATE N_NIMCALL(void, idNodeTableRawInsert__6GKldMfzTVg8s9bklGSGKAQ)(tySequence__K8W16aeLg4OWxniQxtguMw** data, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___7c5Zw7H31uJfWmmhZe9aEqw_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
static N_INLINE(NI, cmpStrings)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValue__uOYuOsiCZAbEPMGwBL8r8g_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, strTableInclReportConflict__tsV7rrfL6ZnfCXBjJk0jUA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n, NIM_BOOL onConflictKeepOld);
N_LIB_PRIVATE N_NIMCALL(void, symTabReplaceRaw__78XM8LhJNkBJHwAWBX5Rog)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** data, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prevSym, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newSym);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_2, "null", 4);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_3, "\033[90m", 5);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_4, "<defined ", 9);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_5, " lines upwards>", 15);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_6, "\033[0m", 4);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_7, "{", 1);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_8, ",", 1);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_9, "\012", 1);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_10, "\"", 1);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_11, "\": ", 3);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_12, "kind", 4);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_13, "\033[34m", 5);
extern TNimType NTI__cNCW9acsSznmEccl1fgQwkw_;
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_14, "name", 4);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_15, "\033[32m", 5);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_16, "id", 2);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_17, "\033[33m", 5);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_18, "position", 8);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_19, "flags", 5);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_20, "[", 1);
extern TNimType NTI__K9ay6LWMat9bUiT9bIbMxpDHw_;
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_21, ", ", 2);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_22, "]", 1);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_23, "typ", 3);
extern TNimType NTI__9a3YiReNVD0IJHWFKgXRe9ag_;
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_24, "sym", 3);
extern TNimType NTI__x2m5g1NpbmDig4wLT3Ylhw_;
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_25, "n", 1);
extern TNimType NTI__G4E4Gxe7oI2Cm03rkiOzQw_;
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_26, "info", 4);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_27, "\\u", 2);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_28, "command line", 12);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_29, "\?\?\?", 3);
extern TNimType NTI__jyh9acXHkhZANSSvPIY7ZLg_;
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_30, "nil", 3);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_31, "intVal", 6);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_32, "floatVal", 8);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_33, "strVal", 6);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_34, "ident", 5);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_35, "sons", 4);
STRING_LITERAL(TM__uRgrUHgaDgkYkoMPsaodqw_36, "}", 1);
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
extern TNimType NTI__Mh9agqM29bm9aP5AUL1x7dZGA_;
extern TNimType NTI__K8W16aeLg4OWxniQxtguMw_;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, indentMore__EAEW3Bgfb2rBayBNQm2DKA_2)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0) {
	(*this_0).indent += ((NI) 2);
}
N_LIB_PRIVATE N_NIMCALL(void, openCurly__EAEW3Bgfb2rBayBNQm2DKA)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0) {
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_7));
	indentMore__EAEW3Bgfb2rBayBNQm2DKA_2(this_0);
	(*this_0).firstItem = NIM_TRUE;
}
N_LIB_PRIVATE N_NIMCALL(void, newlineAndIndent__EAEW3Bgfb2rBayBNQm2DKA_3)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0) {
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_9));
	(*this_0).currentLine += ((NI) 1);
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < (*this_0).indent)) goto LA3;
				i = i_2;
				unsureAsgnRef((void**) (&(*this_0).res), addChar((*this_0).res, 32));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, key__phacdxUw7oWjcmjWuQy9bkg)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, NimStringDesc* key) {
	{
		if (!!((*this_0).firstItem)) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_8));
	}
	LA3_: ;
	(*this_0).firstItem = NIM_FALSE;
	newlineAndIndent__EAEW3Bgfb2rBayBNQm2DKA_3(this_0);
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (key ? key->Sup.len : 0) + 0));
appendString((*this_0).res, key);
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 3));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_11));
}
N_LIB_PRIVATE N_NIMCALL(void, value__IoQuLXtIJvnyXSTPrJspcg)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_13));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTI__cNCW9acsSznmEccl1fgQwkw_)) ? reprEnum((NI)value, (&NTI__cNCW9acsSznmEccl1fgQwkw_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTI__cNCW9acsSznmEccl1fgQwkw_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__FzAGrI1bDlDZrjbkaI7wWw)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, NimStringDesc* value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_15));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (value ? value->Sup.len : 0) + 0));
appendString((*this_0).res, value);
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__llsVIlOlOqDWZCDMxDvp3Q)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, NI64 value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_17));
	}
	LA3_: ;
	addInt__mftMOxbyu0h4yByfs3sqjA((&(*this_0).res), value);
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
	}
	LA7_: ;
}
static N_INLINE(NI, countBits64)(NU64 n) {
	NI result;
	NU64 v;
	result = (NI)0;
	v = n;
	v = (NU64)((NU64)(v) - (NU64)((NU64)((NU64)((NU64)(v) >> (NU64)(1ULL)) & 6148914691236517205ULL)));
	v = (NU64)((NU64)((NU64)(v & 3689348814741910323ULL)) + (NU64)((NU64)((NU64)((NU64)(v) >> (NU64)(2ULL)) & 3689348814741910323ULL)));
	v = (NU64)((NU64)((NU64)(v) + (NU64)((NU64)((NU64)(v) >> (NU64)(4ULL)))) & 1085102592571150095ULL);
	result = ((NI) ((NU64)((NU64)((NU64)((NU64)(v) * (NU64)(72340172838076673ULL))) >> (NU64)(56ULL))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, openBracket__EAEW3Bgfb2rBayBNQm2DKA_4)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0) {
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_20));
}
N_LIB_PRIVATE N_NIMCALL(void, value__ruLxBJWmZYZuNJ1guCKmNQ)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_13));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTI__K9ay6LWMat9bUiT9bIbMxpDHw_)) ? reprEnum((NI)value, (&NTI__K9ay6LWMat9bUiT9bIbMxpDHw_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTI__K9ay6LWMat9bUiT9bIbMxpDHw_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, comma__EAEW3Bgfb2rBayBNQm2DKA_5)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0) {
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 2));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_21));
}
N_LIB_PRIVATE N_NIMCALL(void, closeBracket__EAEW3Bgfb2rBayBNQm2DKA_6)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0) {
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_22));
}
N_LIB_PRIVATE N_NIMCALL(void, value__Hzb0vPKN9benEkKQu05NCSQ)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw value) {
	NI high;
	NI i;
	openBracket__EAEW3Bgfb2rBayBNQm2DKA_4(this_0);
	high = (NI)(countBits64(value) - ((NI) 1));
	i = ((NI) 0);
	{
		tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw v;
		NI i_2;
		v = (tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 <= ((NI) 45))) goto LA3;
				{
					if (!((value &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) (i_2)))&63U)))!=0)) goto LA6_;
					v = ((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) (i_2));
					value__ruLxBJWmZYZuNJ1guCKmNQ(this_0, v);
					{
						if (!!((i == high))) goto LA10_;
						comma__EAEW3Bgfb2rBayBNQm2DKA_5(this_0);
					}
					LA10_: ;
					i += ((NI) 1);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	closeBracket__EAEW3Bgfb2rBayBNQm2DKA_6(this_0);
}
N_LIB_PRIVATE N_NIMCALL(void, value__kpJVt9cnR9aTcWW9bP5ctpOcA)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_13));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)value, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__Hsy1hoKfET3FAJnWke3a8w)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_13));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTI__x2m5g1NpbmDig4wLT3Ylhw_)) ? reprEnum((NI)value, (&NTI__x2m5g1NpbmDig4wLT3Ylhw_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTI__x2m5g1NpbmDig4wLT3Ylhw_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__aJLEBHPURIT7szTDyvtBUA)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw value) {
	NI high;
	NI i;
	openBracket__EAEW3Bgfb2rBayBNQm2DKA_4(this_0);
	high = (NI)(countBits64(value) - ((NI) 1));
	i = ((NI) 0);
	{
		tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw v;
		NI i_2;
		v = (tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 <= ((NI) 42))) goto LA3;
				{
					if (!((value &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) (i_2)))&63U)))!=0)) goto LA6_;
					v = ((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) (i_2));
					value__Hsy1hoKfET3FAJnWke3a8w(this_0, v);
					{
						if (!!((i == high))) goto LA10_;
						comma__EAEW3Bgfb2rBayBNQm2DKA_5(this_0);
					}
					LA10_: ;
					i += ((NI) 1);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	closeBracket__EAEW3Bgfb2rBayBNQm2DKA_6(this_0);
}
N_LIB_PRIVATE N_NIMCALL(void, value__KUWb6zp2ipm1IVHDVNcPJQ)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_13));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)) ? reprEnum((NI)value, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
	}
	LA7_: ;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toYamlChar__WyTOYiqdW29blXR7k3pjktw)(NIM_CHAR c) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	switch (((NU8)(c))) {
	case 0 ... 31:
	case 127 ... 255:
	{
		NimStringDesc* T2_;
		NimStringDesc* T3_;
		T2_ = (NimStringDesc*)0;
		T3_ = (NimStringDesc*)0;
		T3_ = toHex__TwQ1R2wlkmY9ak7KGbc718A(((NU8)(c)), ((NI) 4));
		T2_ = rawNewString((T3_ ? T3_->Sup.len : 0) + 2);
appendString(T2_, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_27));
appendString(T2_, T3_);
		result = T2_;
	}
	break;
	case 39:
	case 34:
	case 92:
	{
		NimStringDesc* T5_;
		T5_ = (NimStringDesc*)0;
		T5_ = rawNewString(2);
appendChar(T5_, 92);
appendChar(T5_, c);
		result = T5_;
	}
	break;
	default:
	{
		result = nimCharToStr(c);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, makeYamlString__P4HN4Rp9arTWym9cdDnUDu8Q)(NimStringDesc* s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	res = copyString(((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (s ? s->Sup.len : 0);
		i_2 = ((NI) 0);
		{
			while (1) {
				NimStringDesc* T9_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
					if (!((NI)((NI)(i + ((NI) 1)) % ((NI) 64)) == ((NI) 0))) goto LA6_;
					res = addChar(res, 34);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_9));
					T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T8_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T8_);
					res = copyString(((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
				}
				LA6_: ;
				T9_ = (NimStringDesc*)0;
				T9_ = toYamlChar__WyTOYiqdW29blXR7k3pjktw(s->data[i]);
				res = resizeString(res, (T9_ ? T9_->Sup.len : 0) + 0);
appendString(res, T9_);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	res = addChar(res, 34);
	T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T10_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T10_);
	return result;
}
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.line));
	return result;
}
static N_INLINE(NI, toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.col));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, lineInfoToStr__o5OvO09cfEJ7lAWvUTH12Yw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T1_;
	NimStringDesc* T2_;
	NI T15_;
	NI T16_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
	T2_ = (NimStringDesc*)0;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = (info.fileIndex < ((NI32) 0));
		if (T5_) goto LA6_;
		T5_ = (conf == ((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL));
		LA6_: ;
		if (!T5_) goto LA7_;
		{
			if (!(info.fileIndex == ((NI32) -3))) goto LA11_;
			T2_ = copyString(((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_28));
		}
		goto LA9_;
		LA11_: ;
		{
			T2_ = copyString(((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_29));
		}
		LA9_: ;
	}
	goto LA3_;
	LA7_: ;
	{
		T2_ = copyString((*conf).m.fileInfos->data[info.fileIndex].shortName);
	}
	LA3_: ;
	T1_[0] = makeYamlString__P4HN4Rp9arTWym9cdDnUDu8Q(T2_);
	T15_ = (NI)0;
	T15_ = toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs(info);
	T1_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T15_)));
	T16_ = (NI)0;
	T16_ = toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs(info);
	T1_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T16_)));
	result = percent___UQfMnMPks8jKz20fTXQy9bQ(T1_, 3);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, value__RbCM2UXVLll9cN4eZagDG6A)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_13));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTI__jyh9acXHkhZANSSvPIY7ZLg_)) ? reprEnum((NI)value, (&NTI__jyh9acXHkhZANSSvPIY7ZLg_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTI__jyh9acXHkhZANSSvPIY7ZLg_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_10));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__22GsmbrIt7ciZ1zdjy1Jvg)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg value) {
	NI high;
	NI i;
	openBracket__EAEW3Bgfb2rBayBNQm2DKA_4(this_0);
	high = (NI)(countBits32(value) - ((NI) 1));
	i = ((NI) 0);
	{
		tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg v;
		NI i_2;
		v = (tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 <= ((NI) 20))) goto LA3;
				{
					if (!((value &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) (i_2)))&31U)))!=0)) goto LA6_;
					v = ((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) (i_2));
					value__RbCM2UXVLll9cN4eZagDG6A(this_0, v);
					{
						if (!!((i == high))) goto LA10_;
						comma__EAEW3Bgfb2rBayBNQm2DKA_5(this_0);
					}
					LA10_: ;
					i += ((NI) 1);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	closeBracket__EAEW3Bgfb2rBayBNQm2DKA_6(this_0);
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, indentLess__EAEW3Bgfb2rBayBNQm2DKA_8)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0) {
	(*this_0).indent -= ((NI) 2);
}
N_LIB_PRIVATE N_NIMCALL(void, closeCurly__EAEW3Bgfb2rBayBNQm2DKA_7)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0) {
	indentLess__EAEW3Bgfb2rBayBNQm2DKA_8(this_0);
	newlineAndIndent__EAEW3Bgfb2rBayBNQm2DKA_3(this_0);
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_36));
}
N_LIB_PRIVATE N_NIMCALL(void, value__PG3EgA9a9albKasBOYELDF6A)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value) {
	NI indexX60gensym123_;
{	{
		if (!(value == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_2));
		goto BeforeRet_;
	}
	LA3_: ;
	indexX60gensym123_ = getOrDefault__ucLvuteXMiAMAvKs77J1uw((*this_0).visited, ((void*) (value)), ((NI) -1));
	{
		if (!(indexX60gensym123_ < ((NI) 0))) goto LA7_;
		X5BX5Deq___7nUN9bEb8it8esEzVF54z3Q((&(*this_0).visited), ((void*) (value)), (*this_0).currentLine);
	}
	goto LA5_;
	LA7_: ;
	{
		{
			if (!(*this_0).useColor) goto LA12_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_3));
		}
		LA12_: ;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 9));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_4));
		addInt__mftMOxbyu0h4yByfs3sqjA((&(*this_0).res), ((NI64) ((NI)((*this_0).currentLine - indexX60gensym123_))));
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 15));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_5));
		{
			if (!(*this_0).useColor) goto LA16_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
		}
		LA16_: ;
		goto BeforeRet_;
	}
	LA5_: ;
	openCurly__EAEW3Bgfb2rBayBNQm2DKA(this_0);
	key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_12));
	value__KUWb6zp2ipm1IVHDVNcPJQ(this_0, (*value).kind);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		NimStringDesc* T23_;
		if (!!(((*this_0).conf == ((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL)))) goto LA20_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_26));
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = lineInfoToStr__o5OvO09cfEJ7lAWvUTH12Yw((*this_0).conf, (*value).info);
		T23_ = (NimStringDesc*)0;
		T23_ = dollar___mZ66tEveFIQokq3arf8Klw(T22_);
		value__FzAGrI1bDlDZrjbkaI7wWw(this_0, T23_);
	}
	LA20_: ;
	{
		if (!!(((*value).flags == 0))) goto LA26_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_19));
		value__22GsmbrIt7ciZ1zdjy1Jvg(this_0, (*value).flags);
	}
	LA26_: ;
	{
		if (!!(((*value).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA30_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_23));
		value__kpJVt9cnR9aTcWW9bP5ctpOcA(this_0, (*(*value).typ).kind);
	}
	goto LA28_;
	LA30_: ;
	{
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_23));
		value__FzAGrI1bDlDZrjbkaI7wWw(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_30));
	}
	LA28_: ;
	switch ((*value).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_31));
		value__llsVIlOlOqDWZCDMxDvp3Q(this_0, (*value)._kind_1.intVal);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 17):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18):
	{
		NimStringDesc* T35_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_32));
		T35_ = (NimStringDesc*)0;
		T35_ = toStrMaxPrecision__ayHojnbqAtgkZF8TXMNMzg((*value)._kind_2.floatVal, ((NimStringDesc*) NIM_NIL));
		value__FzAGrI1bDlDZrjbkaI7wWw(this_0, T35_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_33));
		value__FzAGrI1bDlDZrjbkaI7wWw(this_0, (*value)._kind_3.strVal);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_24));
		value__WBlS070x2bmiH6WMBydj9bA(this_0, (*value)._kind_4.sym);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		{
			if (!!(((*value)._kind_5.ident == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL)))) goto LA41_;
			key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_34));
			value__FzAGrI1bDlDZrjbkaI7wWw(this_0, (*(*value)._kind_5.ident).s);
		}
		LA41_: ;
	}
	break;
	default:
	{
		{
			NIM_BOOL T46_;
			T46_ = (NIM_BOOL)0;
			T46_ = (*this_0).renderSymType;
			if (!(T46_)) goto LA47_;
			T46_ = !(((*value).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA47_: ;
			if (!T46_) goto LA48_;
			key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_23));
			value__uX2gdSRLzvWLVnXyqz6jsg(this_0, (*value).typ);
		}
		LA48_: ;
		{
			NI T52_;
			T52_ = (NI)0;
			T52_ = len__P89cqdlERShb9alU3iC0yj8wast(value);
			if (!(((NI) 0) < T52_)) goto LA53_;
			key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_35));
			openBracket__EAEW3Bgfb2rBayBNQm2DKA_4(this_0);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(value);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA57;
						i = i_2;
						value__PG3EgA9a9albKasBOYELDF6A(this_0, (*value)._kind_6.sons->data[i]);
						{
							NI T60_;
							T60_ = (NI)0;
							T60_ = len__P89cqdlERShb9alU3iC0yj8wast(value);
							if (!!((i == (NI)(T60_ - ((NI) 1))))) goto LA61_;
							comma__EAEW3Bgfb2rBayBNQm2DKA_5(this_0);
						}
						LA61_: ;
						i_2 += ((NI) 1);
					} LA57: ;
				}
			}
			closeBracket__EAEW3Bgfb2rBayBNQm2DKA_6(this_0);
		}
		LA53_: ;
	}
	break;
	}
	closeCurly__EAEW3Bgfb2rBayBNQm2DKA_7(this_0);
	}BeforeRet_: ;
}
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, value__uX2gdSRLzvWLVnXyqz6jsg)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* value) {
	NI indexX60gensym114_;
{	{
		if (!(value == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_2));
		goto BeforeRet_;
	}
	LA3_: ;
	indexX60gensym114_ = getOrDefault__ucLvuteXMiAMAvKs77J1uw((*this_0).visited, ((void*) (value)), ((NI) -1));
	{
		if (!(indexX60gensym114_ < ((NI) 0))) goto LA7_;
		X5BX5Deq___7nUN9bEb8it8esEzVF54z3Q((&(*this_0).visited), ((void*) (value)), (*this_0).currentLine);
	}
	goto LA5_;
	LA7_: ;
	{
		{
			if (!(*this_0).useColor) goto LA12_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_3));
		}
		LA12_: ;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 9));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_4));
		addInt__mftMOxbyu0h4yByfs3sqjA((&(*this_0).res), ((NI64) ((NI)((*this_0).currentLine - indexX60gensym114_))));
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 15));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_5));
		{
			if (!(*this_0).useColor) goto LA16_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
		}
		LA16_: ;
		goto BeforeRet_;
	}
	LA5_: ;
	openCurly__EAEW3Bgfb2rBayBNQm2DKA(this_0);
	key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_12));
	value__kpJVt9cnR9aTcWW9bP5ctpOcA(this_0, (*value).kind);
	key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_16));
	value__llsVIlOlOqDWZCDMxDvp3Q(this_0, ((NI64) ((*value).Sup.id)));
	{
		if (!!(((*value).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA20_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_24));
		value__WBlS070x2bmiH6WMBydj9bA(this_0, (*value).sym);
	}
	LA20_: ;
	{
		if (!(((NI) 0) < countBits64((*value).flags))) goto LA24_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_19));
		value__aJLEBHPURIT7szTDyvtBUA(this_0, (*value).flags);
	}
	LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = ((IL64(35182224621574) &((NU64)1<<((NU)((*value).kind)&63U)))!=0);
		if (!(T28_)) goto LA29_;
		T28_ = !(((*value).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA29_: ;
		if (!T28_) goto LA30_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_25));
		value__PG3EgA9a9albKasBOYELDF6A(this_0, (*value).n);
	}
	LA30_: ;
	{
		NI T34_;
		T34_ = (NI)0;
		T34_ = len__5mJADrRYkP3r9auuiuDZN9cQast(value);
		if (!(((NI) 0) < T34_)) goto LA35_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_35));
		openBracket__EAEW3Bgfb2rBayBNQm2DKA_4(this_0);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(value);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA39;
					i = i_2;
					value__uX2gdSRLzvWLVnXyqz6jsg(this_0, (*value).sons->data[i]);
					{
						NI T42_;
						T42_ = (NI)0;
						T42_ = len__5mJADrRYkP3r9auuiuDZN9cQast(value);
						if (!!((i == (NI)(T42_ - ((NI) 1))))) goto LA43_;
						comma__EAEW3Bgfb2rBayBNQm2DKA_5(this_0);
					}
					LA43_: ;
					i_2 += ((NI) 1);
				} LA39: ;
			}
		}
		closeBracket__EAEW3Bgfb2rBayBNQm2DKA_6(this_0);
	}
	LA35_: ;
	{
		if (!!(((*value).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA47_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_25));
		value__PG3EgA9a9albKasBOYELDF6A(this_0, (*value).n);
	}
	LA47_: ;
	closeCurly__EAEW3Bgfb2rBayBNQm2DKA_7(this_0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__WBlS070x2bmiH6WMBydj9bA)(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA* this_0, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* value) {
	NI indexX60gensym94_;
{	{
		if (!(value == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_2));
		goto BeforeRet_;
	}
	LA3_: ;
	indexX60gensym94_ = getOrDefault__ucLvuteXMiAMAvKs77J1uw((*this_0).visited, ((void*) (value)), ((NI) -1));
	{
		if (!(indexX60gensym94_ < ((NI) 0))) goto LA7_;
		X5BX5Deq___7nUN9bEb8it8esEzVF54z3Q((&(*this_0).visited), ((void*) (value)), (*this_0).currentLine);
	}
	goto LA5_;
	LA7_: ;
	{
		{
			if (!(*this_0).useColor) goto LA12_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_3));
		}
		LA12_: ;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 9));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_4));
		addInt__mftMOxbyu0h4yByfs3sqjA((&(*this_0).res), ((NI64) ((NI)((*this_0).currentLine - indexX60gensym94_))));
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 15));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_5));
		{
			if (!(*this_0).useColor) goto LA16_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_6));
		}
		LA16_: ;
		goto BeforeRet_;
	}
	LA5_: ;
	openCurly__EAEW3Bgfb2rBayBNQm2DKA(this_0);
	key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_12));
	value__IoQuLXtIJvnyXSTPrJspcg(this_0, (*value).kind);
	key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_14));
	value__FzAGrI1bDlDZrjbkaI7wWw(this_0, (*(*value).name).s);
	key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_16));
	value__llsVIlOlOqDWZCDMxDvp3Q(this_0, ((NI64) ((*value).Sup.id)));
	{
		if (!((1572872 &((NU32)1<<((NU)((*value).kind)&31U)))!=0)) goto LA20_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_18));
		value__llsVIlOlOqDWZCDMxDvp3Q(this_0, ((NI64) ((*value).position)));
	}
	LA20_: ;
	{
		if (!(((NI) 0) < countBits64((*value).flags))) goto LA24_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_19));
		value__Hzb0vPKN9benEkKQu05NCSQ(this_0, (*value).flags);
	}
	LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = (*this_0).renderSymType;
		if (!(T28_)) goto LA29_;
		T28_ = !(((*value).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA29_: ;
		if (!T28_) goto LA30_;
		key__phacdxUw7oWjcmjWuQy9bkg(this_0, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_23));
		value__uX2gdSRLzvWLVnXyqz6jsg(this_0, (*value).typ);
	}
	LA30_: ;
	closeCurly__EAEW3Bgfb2rBayBNQm2DKA_7(this_0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, debugSym)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA this_1;
	tyArray__nHXaesL0DJZHyVS07ARPRA T1_;
	nimZeroMem((void*)(&this_1), sizeof(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA));
	initTable__avINVlbIK12XSqjy8oSlzg(((NI) 32), (&this_1.visited));
	this_1.renderSymType = NIM_TRUE;
	this_1.useColor = NIM_TRUE;
	value__WBlS070x2bmiH6WMBydj9bA((&this_1), n);
	nimZeroMem((void*)T1_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T1_[0] = copyString(this_1.res);
	echoBinSafe(T1_, 1);
}
N_LIB_PRIVATE N_NIMCALL(void, debugType)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA this_1;
	tyArray__nHXaesL0DJZHyVS07ARPRA T1_;
	nimZeroMem((void*)(&this_1), sizeof(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA));
	initTable__avINVlbIK12XSqjy8oSlzg(((NI) 32), (&this_1.visited));
	this_1.renderSymType = NIM_TRUE;
	this_1.useColor = NIM_TRUE;
	value__uX2gdSRLzvWLVnXyqz6jsg((&this_1), n);
	nimZeroMem((void*)T1_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T1_[0] = copyString(this_1.res);
	echoBinSafe(T1_, 1);
}
N_LIB_PRIVATE N_NIMCALL(void, debugNode)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA this_1;
	tyArray__nHXaesL0DJZHyVS07ARPRA T1_;
	nimZeroMem((void*)(&this_1), sizeof(tyObject_DebugPrinter__a6duEI3KVtgLLu9cNBssigA));
	initTable__avINVlbIK12XSqjy8oSlzg(((NI) 32), (&this_1.visited));
	this_1.useColor = NIM_TRUE;
	value__PG3EgA9a9albKasBOYELDF6A((&this_1), n);
	nimZeroMem((void*)T1_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T1_[0] = copyString(this_1.res);
	echoBinSafe(T1_, 1);
}
static N_INLINE(NI, nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo)(NI h, NI maxHash) {
	NI result;
	result = (NI)0;
	result = (NI)((NI)((NI)(((NI) 5) * h) + ((NI) 1)) & maxHash);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA t, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	NI h;
	NI T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*name).h & T1_);
	{
		while (1) {
			NI T12_;
			result = t.data->data[h];
			{
				if (!(result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA6_;
				goto LA2;
			}
			LA6_: ;
			{
				if (!((*(*result).name).Sup.id == (*name).Sup.id)) goto LA10_;
				goto LA2;
			}
			LA10_: ;
			T12_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T12_);
		}
	} LA2: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, mustRehash__B5utQwGyZRj1lQY2mjeMBw)(NI length, NI counter) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((NI)(length * ((NI) 2)) < (NI)(counter * ((NI) 3)));
	if (T1_) goto LA2_;
	T1_ = ((NI)(length - counter) < ((NI) 4));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, strTableRawInsert__SHWbts1Rvx7KpPzj7sTOjw)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** data, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n) {
	NI h;
	NI T1_;
{	T1_ = (((*data) ? (*data)->Sup.len : 0)-1);
	h = (NI)((*(*n).name).h & T1_);
	{
		while (1) {
			NI T8_;
			if (!!(((*data)->data[h] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3;
			{
				if (!((*data)->data[h] == n)) goto LA6_;
				goto BeforeRet_;
			}
			LA6_: ;
			T8_ = (((*data) ? (*data)->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T8_);
		} LA3: ;
	}
	asgnRef((void**) (&(*data)->data[h]), n);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, strTableEnlarge__CVRANnnfZDXMACWb4B1HCA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t) {
	tySequence__DfgJFJEYoj4YBAHLZPl5lQ* n;
	NI T1_;
	tySequence__DfgJFJEYoj4YBAHLZPl5lQ* T10_;
	n = (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*)0;
	T1_ = ((*t).data ? (*t).data->Sup.len : 0);
	n = (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) newSeq((&NTI__DfgJFJEYoj4YBAHLZPl5lQ_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
		colontmp_ = T3_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA5;
				i = res;
				{
					if (!!(((*t).data->data[i] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA8_;
					strTableRawInsert__SHWbts1Rvx7KpPzj7sTOjw((&n), (*t).data->data[i]);
				}
				LA8_: ;
				res += ((NI) 1);
			} LA5: ;
		}
	}
	T10_ = (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*)0;
	T10_ = (*t).data;
	unsureAsgnRef((void**) (&(*t).data), n);
	n = T10_;
}
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__tyTgUybFIoow4CX2l5beug)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n) {
	{
		NI T3_;
		NIM_BOOL T4_;
		T3_ = ((*t).data ? (*t).data->Sup.len : 0);
		T4_ = (NIM_BOOL)0;
		T4_ = mustRehash__B5utQwGyZRj1lQY2mjeMBw(T3_, (*t).counter);
		if (!T4_) goto LA5_;
		strTableEnlarge__CVRANnnfZDXMACWb4B1HCA(t);
	}
	LA5_: ;
	strTableRawInsert__SHWbts1Rvx7KpPzj7sTOjw((&(*t).data), n);
	(*t).counter += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2)(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	{
		while (1) {
			NI T3_;
			T3_ = ((tab.data ? tab.data->Sup.len : 0)-1);
			if (!((*ti).h <= T3_)) goto LA2;
			result = tab.data->data[(*ti).h];
			(*ti).h += ((NI) 1);
			{
				if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA6_;
				goto LA1;
			}
			LA6_: ;
		} LA2: ;
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw)(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	(*ti).h = ((NI) 0);
	{
		if (!(tab.counter == ((NI) 0))) goto LA3_;
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		result = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2(ti, tab);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getModule__xfh8ar7fDxVX2A4OO9b5sqQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	result = s;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T3_ = !(((*result).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
			LA4_: ;
			if (!T3_) goto LA2;
			result = (*result).owner;
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, idTableRawGet__SaVgzV5UjaVvopbOluf3NA)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q t, NI key) {
	NI result;
	NI h;
	NI T1_;
{	result = (NI)0;
	h = (NI)0;
	T1_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(key & T1_);
	{
		while (1) {
			NI T8_;
			if (!!((t.data->data[h].key == ((tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*) NIM_NIL)))) goto LA3;
			{
				if (!((*t.data->data[h].key).id == key)) goto LA6_;
				result = h;
				goto BeforeRet_;
			}
			LA6_: ;
			T8_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T8_);
		} LA3: ;
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, idTableRawInsert__psi7yP9bBH1cFhQHDpcKjQA)(tySequence__Mh9agqM29bm9aP5AUL1x7dZGA** data, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key, RootObj* val) {
	NI h;
	NI T1_;
	h = (NI)0;
	T1_ = (((*data) ? (*data)->Sup.len : 0)-1);
	h = (NI)((*key).id & T1_);
	{
		while (1) {
			NI T4_;
			if (!!(((*data)->data[h].key == ((tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*) NIM_NIL)))) goto LA3;
			T4_ = (((*data) ? (*data)->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T4_);
		} LA3: ;
	}
	asgnRef((void**) (&(*data)->data[h].key), key);
	asgnRef((void**) (&(*data)->data[h].val), val);
}
N_LIB_PRIVATE N_NIMCALL(void, idTablePut__anELyz7VLsjbCIoxLpxbfQ)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key, RootObj* val) {
	NI index;
	tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* n;
	index = (NI)0;
	n = (tySequence__Mh9agqM29bm9aP5AUL1x7dZGA*)0;
	index = idTableRawGet__SaVgzV5UjaVvopbOluf3NA((*t), (*key).id);
	{
		if (!(((NI) 0) <= index)) goto LA3_;
		asgnRef((void**) (&(*t).data->data[index].val), val);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI T8_;
			NIM_BOOL T9_;
			NI T12_;
			tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* T21_;
			T8_ = ((*t).data ? (*t).data->Sup.len : 0);
			T9_ = (NIM_BOOL)0;
			T9_ = mustRehash__B5utQwGyZRj1lQY2mjeMBw(T8_, (*t).counter);
			if (!T9_) goto LA10_;
			T12_ = ((*t).data ? (*t).data->Sup.len : 0);
			n = (tySequence__Mh9agqM29bm9aP5AUL1x7dZGA*) newSeq((&NTI__Mh9agqM29bm9aP5AUL1x7dZGA_), ((NI) ((NI)(T12_ * ((NI) 2)))));
			{
				NI i;
				NI colontmp_;
				NI T14_;
				NI res;
				i = (NI)0;
				colontmp_ = (NI)0;
				T14_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
				colontmp_ = T14_;
				res = ((NI) 0);
				{
					while (1) {
						if (!(res <= colontmp_)) goto LA16;
						i = res;
						{
							if (!!(((*t).data->data[i].key == ((tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*) NIM_NIL)))) goto LA19_;
							idTableRawInsert__psi7yP9bBH1cFhQHDpcKjQA((&n), (*t).data->data[i].key, (*t).data->data[i].val);
						}
						LA19_: ;
						res += ((NI) 1);
					} LA16: ;
				}
			}
			T21_ = (tySequence__Mh9agqM29bm9aP5AUL1x7dZGA*)0;
			T21_ = (*t).data;
			unsureAsgnRef((void**) (&(*t).data), n);
			n = T21_;
		}
		LA10_: ;
		idTableRawInsert__psi7yP9bBH1cFhQHDpcKjQA((&(*t).data), key, val);
		(*t).counter += ((NI) 1);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(RootObj*, idTableGet__K5M5T7J9c0H7M5ahfeRl8xw)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key) {
	RootObj* result;
	NI index;
	result = (RootObj*)0;
	index = idTableRawGet__SaVgzV5UjaVvopbOluf3NA(t, (*key).id);
	{
		if (!(((NI) 0) <= index)) goto LA3_;
		result = t.data->data[index].val;
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((RootObj*) NIM_NIL);
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameValue__uOYuOsiCZAbEPMGwBL8r8g)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T6_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T7_;
			if (!((*b).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*b).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15))) goto LA4_;
			T6_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T7_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			result = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(T6_, T7_);
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18):
	{
		{
			if (!((*b).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) && (*b).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18))) goto LA11_;
			result = ((*a)._kind_2.floatVal == (*b)._kind_2.floatVal);
		}
		LA11_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		{
			if (!((*b).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*b).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA16_;
			result = eqStrings((*a)._kind_3.strVal, (*b)._kind_3.strVal);
		}
		LA16_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, strTableInclReportConflict__tsV7rrfL6ZnfCXBjJk0jUA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n, NIM_BOOL onConflictKeepOld) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	NI h;
	NI T1_;
	NI replaceSlot;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
	h = (NI)((*(*n).name).h & T1_);
	replaceSlot = ((NI) -1);
	{
		while (1) {
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
			NI T16_;
			it = (*t).data->data[h];
			{
				if (!(it == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA6_;
				goto LA2;
			}
			LA6_: ;
			{
				if (!((*(*it).name).Sup.id == (*(*n).name).Sup.id)) goto LA10_;
				{
					if (!(it == n)) goto LA14_;
					result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
					goto BeforeRet_;
				}
				LA14_: ;
				replaceSlot = h;
			}
			LA10_: ;
			T16_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T16_);
		}
	} LA2: ;
	{
		if (!(((NI) 0) <= replaceSlot)) goto LA19_;
		{
			if (!!(onConflictKeepOld)) goto LA23_;
			asgnRef((void**) (&(*t).data->data[replaceSlot]), n);
		}
		LA23_: ;
		result = (*t).data->data[replaceSlot];
		goto BeforeRet_;
	}
	goto LA17_;
	LA19_: ;
	{
		NI T26_;
		NIM_BOOL T27_;
		T26_ = ((*t).data ? (*t).data->Sup.len : 0);
		T27_ = (NIM_BOOL)0;
		T27_ = mustRehash__B5utQwGyZRj1lQY2mjeMBw(T26_, (*t).counter);
		if (!T27_) goto LA28_;
		strTableEnlarge__CVRANnnfZDXMACWb4B1HCA(t);
		strTableRawInsert__SHWbts1Rvx7KpPzj7sTOjw((&(*t).data), n);
	}
	goto LA17_;
	LA28_: ;
	{
		asgnRef((void**) (&(*t).data->data[h]), n);
	}
	LA17_: ;
	(*t).counter += ((NI) 1);
	result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameIgnoreBacktickGensymInfo__79a58vqHQbOF5NzKLzjPg9aA)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI i;
	NI j;
{	result = (NIM_BOOL)0;
	{
		if (!!(((NU8)(a->data[((NI) 0)]) == (NU8)(b->data[((NI) 0)])))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	alen = (NI)((a ? a->Sup.len : 0) - ((NI) 1));
	{
		while (1) {
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (((NI) 0) < alen);
			if (!(T7_)) goto LA8_;
			T7_ = !(((NU8)(a->data[alen]) == (NU8)(96)));
			LA8_: ;
			if (!T7_) goto LA6;
			alen -= ((NI) 1);
		} LA6: ;
	}
	{
		if (!(alen <= ((NI) 0))) goto LA11_;
		alen = (a ? a->Sup.len : 0);
	}
	LA11_: ;
	i = ((NI) 1);
	j = ((NI) 1);
	{
		while (1) {
			NIM_CHAR aa;
			NIM_CHAR bb;
			{
				while (1) {
					NIM_BOOL T17_;
					T17_ = (NIM_BOOL)0;
					T17_ = (i < alen);
					if (!(T17_)) goto LA18_;
					T17_ = ((NU8)(a->data[i]) == (NU8)(95));
					LA18_: ;
					if (!T17_) goto LA16;
					i += ((NI) 1);
				} LA16: ;
			}
			{
				while (1) {
					NIM_BOOL T21_;
					T21_ = (NIM_BOOL)0;
					T21_ = (j < (b ? b->Sup.len : 0));
					if (!(T21_)) goto LA22_;
					T21_ = ((NU8)(b->data[j]) == (NU8)(95));
					LA22_: ;
					if (!T21_) goto LA20;
					j += ((NI) 1);
				} LA20: ;
			}
			{
				if (!(i < alen)) goto LA25_;
				aa = nsuToLowerAsciiChar(a->data[i]);
			}
			goto LA23_;
			LA25_: ;
			{
				aa = 0;
			}
			LA23_: ;
			{
				if (!(j < (b ? b->Sup.len : 0))) goto LA30_;
				bb = nsuToLowerAsciiChar(b->data[j]);
			}
			goto LA28_;
			LA30_: ;
			{
				bb = 0;
			}
			LA28_: ;
			{
				if (!!(((NU8)(aa) == (NU8)(bb)))) goto LA35_;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			LA35_: ;
			{
				if (!(alen <= i)) goto LA39_;
				{
					if (!((b ? b->Sup.len : 0) <= j)) goto LA43_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				LA43_: ;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			goto LA37_;
			LA39_: ;
			{
				if (!((b ? b->Sup.len : 0) <= j)) goto LA46_;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			goto LA37_;
			LA46_: ;
			LA37_: ;
			i += ((NI) 1);
			j += ((NI) 1);
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getNamedParamFromList__AuQyLRN9a3PM9cDeuxoao3hA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* list, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(list);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*(*list)._kind_6.sons->data[i])._kind_4.sym;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*(*it).name).Sup.id == (*ident).Sup.id);
					if (T6_) goto LA7_;
					T6_ = sameIgnoreBacktickGensymInfo__79a58vqHQbOF5NzKLzjPg9aA((*(*it).name).s, (*ident).s);
					LA7_: ;
					if (!T6_) goto LA8_;
					result = it;
					goto BeforeRet_;
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIdentIter__9bSCoSykDuXHhkzoBXiof6Q)(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	NI h;
	NI T1_;
	NI start;
	NI T13_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = ((tab.data ? tab.data->Sup.len : 0)-1);
	h = (NI)((*ti).h & T1_);
	start = h;
	result = tab.data->data[h];
	{
		while (1) {
			NI T8_;
			if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3;
			{
				if (!((*(*result).name).Sup.id == (*(*ti).name).Sup.id)) goto LA6_;
				goto LA2;
			}
			LA6_: ;
			T8_ = ((tab.data ? tab.data->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T8_);
			{
				if (!(h == start)) goto LA11_;
				result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
				goto LA2;
			}
			LA11_: ;
			result = tab.data->data[h];
		} LA3: ;
	} LA2: ;
	T13_ = ((tab.data ? tab.data->Sup.len : 0)-1);
	(*ti).h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T13_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, initIdentIter__9bOoZ7latEpanbVkjFO7xFQ)(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	(*ti).h = (*s).h;
	unsureAsgnRef((void**) (&(*ti).name), s);
	{
		if (!(tab.counter == ((NI) 0))) goto LA3_;
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		result = nextIdentIter__9bSCoSykDuXHhkzoBXiof6Q(ti, tab);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIdentExcluding__nWv58txbq3B5NUvjC6qnSA)(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* excluding) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	NI h;
	NI T1_;
	NI start;
	NI T16_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = ((tab.data ? tab.data->Sup.len : 0)-1);
	h = (NI)((*ti).h & T1_);
	start = h;
	result = tab.data->data[h];
	{
		while (1) {
			NI T11_;
			if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3;
			{
				NIM_BOOL T6_;
				NIM_BOOL T8_;
				T6_ = (NIM_BOOL)0;
				T6_ = ((*(*result).name).Sup.id == (*(*ti).name).Sup.id);
				if (!(T6_)) goto LA7_;
				T8_ = (NIM_BOOL)0;
				T8_ = contains__R6uRTGpl30Ofaw4Ni3vawA(excluding, (*result).Sup.id);
				T6_ = !(T8_);
				LA7_: ;
				if (!T6_) goto LA9_;
				goto LA2;
			}
			LA9_: ;
			T11_ = ((tab.data ? tab.data->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T11_);
			{
				if (!(h == start)) goto LA14_;
				result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
				goto LA2;
			}
			LA14_: ;
			result = tab.data->data[h];
		} LA3: ;
	} LA2: ;
	T16_ = ((tab.data ? tab.data->Sup.len : 0)-1);
	(*ti).h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T16_);
	{
		NIM_BOOL T19_;
		T19_ = (NIM_BOOL)0;
		T19_ = !((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T19_)) goto LA20_;
		T19_ = contains__R6uRTGpl30Ofaw4Ni3vawA(excluding, (*result).Sup.id);
		LA20_: ;
		if (!T19_) goto LA21_;
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}
	LA21_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, firstIdentExcluding__ZgFGN4FdEZomWhiPqs5O3Q)(tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* excluding) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	(*ti).h = (*s).h;
	unsureAsgnRef((void**) (&(*ti).name), s);
	{
		if (!(tab.counter == ((NI) 0))) goto LA3_;
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		result = nextIdentExcluding__nWv58txbq3B5NUvjC6qnSA(ti, tab, excluding);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* field) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					result = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*n)._kind_6.sons->data[i], field);
					{
						if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA7_;
						goto BeforeRet_;
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA12_;
			result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
			goto BeforeRet_;
		}
		LA12_: ;
		result = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*n)._kind_6.sons->data[((NI) 0)], field);
		{
			if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA16_;
			goto BeforeRet_;
		}
		LA16_: ;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA20;
					i_3 = i_4;
					switch ((*(*n)._kind_6.sons->data[i_3]).kind) {
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T22_;
						T22_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T22_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i_3]);
						result = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg(T22_, field);
						{
							if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA25_;
							goto BeforeRet_;
						}
						LA25_: ;
					}
					break;
					default:
					{
						result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
						goto BeforeRet_;
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			if (!((*(*(*n)._kind_4.sym).name).Sup.id == (*field).Sup.id)) goto LA31_;
			result = (*n)._kind_4.sym;
		}
		LA31_: ;
	}
	break;
	default:
	{
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, idNodeTableRawGet__gZVj7dpnZcnics5OMZbxkA)(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key) {
	NI result;
	NI h;
	NI T1_;
{	result = (NI)0;
	h = (NI)0;
	T1_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*key).id & T1_);
	{
		while (1) {
			NI T8_;
			if (!!((t.data->data[h].key == ((tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*) NIM_NIL)))) goto LA3;
			{
				if (!((*t.data->data[h].key).id == (*key).id)) goto LA6_;
				result = h;
				goto BeforeRet_;
			}
			LA6_: ;
			T8_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T8_);
		} LA3: ;
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, idNodeTableGet__6wztwviRk10SZ9cTP17EzEQ)(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NI index;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	index = (NI)0;
	index = idNodeTableRawGet__gZVj7dpnZcnics5OMZbxkA(t, key);
	{
		if (!(((NI) 0) <= index)) goto LA3_;
		result = t.data->data[index].val;
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, idNodeTableRawInsert__6GKldMfzTVg8s9bklGSGKAQ)(tySequence__K8W16aeLg4OWxniQxtguMw** data, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val) {
	NI h;
	NI T1_;
	h = (NI)0;
	T1_ = (((*data) ? (*data)->Sup.len : 0)-1);
	h = (NI)((*key).id & T1_);
	{
		while (1) {
			NI T4_;
			if (!!(((*data)->data[h].key == ((tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*) NIM_NIL)))) goto LA3;
			T4_ = (((*data) ? (*data)->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T4_);
		} LA3: ;
	}
	asgnRef((void**) (&(*data)->data[h].key), key);
	asgnRef((void**) (&(*data)->data[h].val), val);
}
N_LIB_PRIVATE N_NIMCALL(void, idNodeTablePut__q49bPlVa9aAaI9bWhgzYAzoBg)(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA* t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val) {
	NI index;
	index = idNodeTableRawGet__gZVj7dpnZcnics5OMZbxkA((*t), key);
	{
		if (!(((NI) 0) <= index)) goto LA3_;
		asgnRef((void**) (&(*t).data->data[index].val), val);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI T8_;
			NIM_BOOL T9_;
			tySequence__K8W16aeLg4OWxniQxtguMw* n;
			NI T12_;
			tySequence__K8W16aeLg4OWxniQxtguMw* T21_;
			T8_ = ((*t).data ? (*t).data->Sup.len : 0);
			T9_ = (NIM_BOOL)0;
			T9_ = mustRehash__B5utQwGyZRj1lQY2mjeMBw(T8_, (*t).counter);
			if (!T9_) goto LA10_;
			n = (tySequence__K8W16aeLg4OWxniQxtguMw*)0;
			T12_ = ((*t).data ? (*t).data->Sup.len : 0);
			n = (tySequence__K8W16aeLg4OWxniQxtguMw*) newSeq((&NTI__K8W16aeLg4OWxniQxtguMw_), ((NI) ((NI)(T12_ * ((NI) 2)))));
			{
				NI i;
				NI colontmp_;
				NI T14_;
				NI res;
				i = (NI)0;
				colontmp_ = (NI)0;
				T14_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
				colontmp_ = T14_;
				res = ((NI) 0);
				{
					while (1) {
						if (!(res <= colontmp_)) goto LA16;
						i = res;
						{
							if (!!(((*t).data->data[i].key == ((tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*) NIM_NIL)))) goto LA19_;
							idNodeTableRawInsert__6GKldMfzTVg8s9bklGSGKAQ((&n), (*t).data->data[i].key, (*t).data->data[i].val);
						}
						LA19_: ;
						res += ((NI) 1);
					} LA16: ;
				}
			}
			T21_ = (tySequence__K8W16aeLg4OWxniQxtguMw*)0;
			T21_ = (*t).data;
			unsureAsgnRef((void**) (&(*t).data), n);
			n = T21_;
		}
		LA10_: ;
		idNodeTableRawInsert__6GKldMfzTVg8s9bklGSGKAQ((&(*t).data), key, val);
		(*t).counter += ((NI) 1);
	}
	LA1_: ;
}
static N_INLINE(NI, cmpStrings)(NimStringDesc* a, NimStringDesc* b) {
	NI result;
	NI alen;
	NI blen;
	NI minlen;
	result = (NI)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	minlen = ((alen <= blen) ? alen : blen);
	{
		int T5_;
		if (!(((NI) 0) < minlen)) goto LA3_;
		T5_ = (int)0;
		T5_ = memcmp(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((size_t) (minlen)));
		result = ((NI) (T5_));
		{
			if (!(result == ((NI) 0))) goto LA8_;
			result = (NI)(alen - blen);
		}
		LA8_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = (NI)(alen - blen);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValue__uOYuOsiCZAbEPMGwBL8r8g_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T6_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T7_;
			if (!((*b).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*b).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15))) goto LA4_;
			T6_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T7_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			result = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T6_, T7_);
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18):
	{
		{
			if (!((*b).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) && (*b).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18))) goto LA11_;
			result = ((*a)._kind_2.floatVal <= (*b)._kind_2.floatVal);
		}
		LA11_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		{
			if (!((*b).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*b).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA16_;
			result = (cmpStrings((*a)._kind_3.strVal, (*b)._kind_3.strVal) <= 0);
		}
		LA16_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA, weakLeValue__u0tFw6hmOCjNH0Gl9c619aMw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA result;
	result = (tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*a).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*a).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22)));
		if (T3_) goto LA4_;
		T3_ = !(((*b).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*b).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22)));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 0);
	}
	goto LA1_;
	LA5_: ;
	{
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = leValue__uOYuOsiCZAbEPMGwBL8r8g_2(a, b);
			if (!T10_) goto LA11_;
			result = ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 2);
		}
		goto LA8_;
		LA11_: ;
		{
			result = ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 1);
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getSymFromList__aHh3vzt6upPNMkKnONiMRw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* list, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident, NI start) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(list);
		i_2 = start;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!((*(*list)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA6_;
					result = (*(*list)._kind_6.sons->data[i])._kind_4.sym;
					{
						if (!((*(*result).name).Sup.id == (*ident).Sup.id)) goto LA10_;
						goto BeforeRet_;
					}
					LA10_: ;
				}
				goto LA4_;
				LA6_: ;
				{
					result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
					goto BeforeRet_;
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, strTableIncl__4C9ciVlXutN6a0CSSeSkVDA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n, NIM_BOOL onConflictKeepOld) {
	NIM_BOOL result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (NIM_BOOL)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = strTableInclReportConflict__tsV7rrfL6ZnfCXBjJk0jUA(t, n, onConflictKeepOld);
	result = !((T1_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConvCastAndClosure__esBhdYyFV8ZlnsxfarHAfQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 68):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155):
			{
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61):
			{
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isAddrNode__OTZyO2oJpdYpHVBZuRXuRQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		{
			NIM_BOOL T5_;
			T5_ = (NIM_BOOL)0;
			T5_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T5_)) goto LA6_;
			T5_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 16));
			LA6_: ;
			if (!T5_) goto LA7_;
			result = NIM_TRUE;
		}
		goto LA3_;
		LA7_: ;
		{
			result = NIM_FALSE;
		}
		LA3_: ;
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, listSymbolNames__8Z1zCwaGnI7ov1q9bc6s4uQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** symbols, NI symbolsLen_0) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** sym;
		NI i;
		sym = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < symbolsLen_0)) goto LA3;
				sym = &symbols[i];
				{
					if (!(((NI) 0) < (result ? result->Sup.len : 0))) goto LA6_;
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__uRgrUHgaDgkYkoMPsaodqw_21));
				}
				LA6_: ;
				result = resizeString(result, ((*(*(*sym)).name).s ? (*(*(*sym)).name).s->Sup.len : 0) + 0);
appendString(result, (*(*(*sym)).name).s);
				i += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, symTabReplaceRaw__78XM8LhJNkBJHwAWBX5Rog)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** data, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prevSym, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newSym) {
	NI h;
	NI T1_;
{	T1_ = (((*data) ? (*data)->Sup.len : 0)-1);
	h = (NI)((*(*prevSym).name).h & T1_);
	{
		while (1) {
			NI T8_;
			if (!!(((*data)->data[h] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3;
			{
				if (!((*data)->data[h] == prevSym)) goto LA6_;
				asgnRef((void**) (&(*data)->data[h]), newSym);
				goto BeforeRet_;
			}
			LA6_: ;
			T8_ = (((*data) ? (*data)->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T8_);
		} LA3: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, symTabReplace__mq4tDXMjV9aoOV0jJhDFqKA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prevSym, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newSym) {
	symTabReplaceRaw__78XM8LhJNkBJHwAWBX5Rog((&(*t).data), prevSym, newSym);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDiscriminantField__OTZyO2oJpdYpHVBZuRXuRQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46))) goto LA3_;
		result = (((*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 20))&63U)))!=0);
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45))) goto LA6_;
		result = (((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 20))&63U)))!=0);
	}
	goto LA1_;
	LA6_: ;
	{
		result = NIM_FALSE;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, strTableContains__qQqj4cZyGcSQKBqbLx4Alg)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n) {
	NIM_BOOL result;
	NI h;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*(*n).name).h & T1_);
	{
		while (1) {
			NI T8_;
			if (!!((t.data->data[h] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3;
			{
				if (!(t.data->data[h] == n)) goto LA6_;
				result = NIM_TRUE;
				goto BeforeRet_;
			}
			LA6_: ;
			T8_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__9bzOSawou0eb9apAqvIEoEGgastalgo(h, T8_);
		} LA3: ;
	}
	result = NIM_FALSE;
	}BeforeRet_: ;
	return result;
}
